@@ -200,12 +200,16 @@ if test -z "$bootstrap"; then
     TESTS="$TESTS
 lib/tests/dirent/90-readdir.c
 lib/tests/io/90-stat.c
+lib/tests/mes/90-abtod.c
+lib/tests/mes/90-dtoab.c
+lib/tests/posix/90-execlp.c
 lib/tests/posix/90-unsetenv.c
 lib/tests/signal/90-signal.c
 lib/tests/stdio/90-fopen.c
 lib/tests/stdio/90-fopen-append.c
 lib/tests/stdio/90-fread-fwrite.c
 lib/tests/stdio/90-fseek.c
+lib/tests/stdio/90-sprintf.c
 lib/tests/stdlib/90-strtol.c
 lib/tests/string/90-snprintf.c
 lib/tests/string/90-strpbrk.c
@@ -222,7 +226,7 @@ lib/tests/scaffold/a1-global-no-clobber.c
 fi
 
 XFAIL_TESTS="
-lib/tests/stdio/90-sprintf.c
+lib/tests/mes/90-abtod.c
 lib/tests/stdio/90-sprintf.c
 "
 
@@ -232,6 +236,7 @@ lib/tests/scaffold/17-compare-unsigned-char-le.c
 lib/tests/scaffold/17-compare-unsigned-short-le.c
 lib/tests/scaffold/66-local-char-array.c
 lib/tests/scaffold/72-typedef-struct-def-local.c
+lib/tests/mes/90-dtoab.c
 lib/tests/scaffold/90-goto-var.c
 lib/tests/scaffold/91-goto-array.c
 "
@@ -248,11 +253,6 @@ lib/tests/scaffold/a0-call-trunc-int.c
     fi
 fi
 
-if test $mes_cpu = x86; then
-    XFAIL_TESTS="$XFAIL_TESTS
-"
-fi
-
 if test $mes_cpu = x86_64; then
     XFAIL_TESTS="$XFAIL_TESTS
 lib/tests/stdio/70-printf-stdarg.c
@@ -261,10 +261,12 @@ fi
 
 if test $compiler = gcc; then
     XFAIL_TESTS="$XFAIL_TESTS
+lib/tests/mes/90-abtod.c
 "
 
     if test $mes_cpu = x86; then
         XFAIL_TESTS="$XFAIL_TESTS
+lib/tests/mes/90-dtoab.c
 "
     fi
 
