@@ -20,69 +20,39 @@
 
 set -e
 
-VERSION=0.20
+VERSION=0.21
 srcdir=${srcdir-$(dirname $0)}
 . ${srcdest}build-aux/trace.sh
 
-# parse --with-system-libc
-cmdline=$(echo " $@")
-p=${cmdline/ --with-system-libc/}
-if test "$p" != "$cmdline"; then
-    mes_libc=${mes_libc-system}
-else
-    mes_libc=mes
-fi
+# parse arguments
+while [ $# -gt 0 ]; do
+    case $1 in
+        (--with-courage)
+            courageous=true
+            ;;
+        (--with-system-libc)
+            mes_libc=system
+            ;;
+        (--build=*)
+            build=${1#--build=}
+            ;;
+        (--host=*)
+            host=${1#--host=}
+            ;;
+        (--prefix=*)
+            prefix=${1#--prefix=}
+            ;;
+        (--program-prefix=*)
+            program_prefix=${1#--program-prefix=}
+            ;;
+    esac
+    shift
+done
 
-# parse --with-courage
-cmdline=$(echo " $@")
-p=${cmdline/ --with-courage/}
-if test "$p" != "$cmdline"; then
-    courageous=true
-else
-    courageous=false
-fi
-
-# parse --prefix=PREFIX
-p=${cmdline/ --prefix=/ -prefix=}
-if test "$p" != "$cmdline"; then
-    p=${p##* -prefix=}
-    p=${p% *}
-    p=${p% -*}
-    prefix=${p-/usr/local}
-else
-    prefix=${prefix-/usr/local}
-fi
-
-# parse --build=BUILD
-p=${cmdline/ --build=/ -build=}
-if [ "$p" != "$cmdline" ]; then
-    p=${p##* -build=}
-    p=${p% *}
-    p=${p% -*}
-    build=${p-$build}
-else
-    build=$build
-fi
-
-# parse --host=HOST
-p=${cmdline/ --host=/ -host=}
-if [ "$p" != "$cmdline" ]; then
-    p=${p##* -host=}
-    p=${p% *}
-    p=${p% -*}
-    host=${p-$build}
-elif test -n "$build"; then
-    host=${host-$build}
-fi
-
-# parse --program-prefix=
-p=${cmdline/ --program-prefix=/ -program-prefix=}
-if test "$p" != "$cmdline"; then
-    p=${p##* -program-prefix=}
-    p=${p% *}
-    p=${p% -*}
-    program_prefix=$p
-fi
+prefix=${prefix-/usr/local}
+mes_libc=${mes_libc-mes}
+courageous=${courageous-false}
+host=${host-$build}
 
 AR=${AR-$(command -v ar)} || true
 BASH=${BASH-$(command -v bash)}
@@ -124,9 +94,9 @@ else
 fi
 bindir=$(eval echo ${bindir-$prefix/bin})
 datadir=$(eval echo ${datadir-$prefix/share})
-docdir=$(eval echo ${docdir-$datadir/doc/mes-$VERSION})
+docdir=$(eval echo ${docdir-$datadir/doc/mes})
 infodir=$(eval echo ${infodir-$datadir/info})
-includedir=$(eval echo ${libdir-$prefix/include})
+includedir=$(eval echo ${includedir-$prefix/include})
 libdir=$(eval echo ${libdir-$prefix/lib})
 pkgdatadir=$(eval echo ${pkgdatadir-$datadir/mes})
 mandir=$(eval echo ${mandir-$datadir/man})
@@ -140,6 +110,7 @@ subst () {
     -e s,"@PACKAGE_NAME@,$PACKAGE_NAME,"\
     -e s,"@PACKAGE_BUGREPORT@,$PACKAGE_BUGREPORT,"\
     -e s,"@VERSION@,$VERSION,"\
+    -e s,"@bootstrap@,yes,"\
     -e s,"@build@,$build,"\
     -e s,"@host@,$host,"\
     -e s,"@compiler@,$compiler,"\
@@ -283,7 +254,7 @@ GNU Mes is configured for
    system:   $mes_system
 
 Run:
-  ./build.sh      to build mes
-  ./check.sh      to check mes
-  ./install.sh    to install mes
+  sh build.sh      to build mes
+  sh check.sh      to check mes
+  sh install.sh    to install mes
 EOF
