@@ -122,7 +122,7 @@ extensive examples, including parsers for the Javascript and C99 languages.")
 
 (define-public mes
   (let ((triplet "i686-unknown-linux-gnu")
-        (version "0.20"))
+        (version "0.21"))
     (package
       (name "mes")
       (version version)
@@ -131,7 +131,7 @@ extensive examples, including parsers for the Javascript and C99 languages.")
                 (uri (string-append
                       "https://ftp.gnu.org/pub/gnu/mes/mes-" version ".tar.gz"))
                 (sha256
-                 (base32 #!mes!# "06qkwkahcpzk5v4qydpvcvzm7lx8g8pflc48f9l7bpjz6hl5lk4s"))))
+                 (base32 #!mes!# "04pajp8v31na34ls4730ig5f6miiplhdvkmsb9ls1b8bbmw2vb4n"))))
       (build-system gnu-build-system)
       (supported-systems '("i686-linux" "x86_64-linux"))
       (propagated-inputs
@@ -164,7 +164,7 @@ Guile.")
       (license gpl3+))))
 
 (define-public mes.git
- (let ((version "0.20")
+ (let ((version "0.21")
         (revision "0")
         (commit (read-string (open-pipe "git show HEAD | head -1 | cut -d ' ' -f 2" OPEN_READ))))
     (package
