@@ -18,7 +18,8 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <libmes.h>
+#include <mes/lib.h>
+#include <errno.h>
 #include <unistd.h>
 
 int
@@ -33,11 +34,17 @@ execvp (char const *file_name, char *const argv[])
     }
   if (__mes_debug ())
     {
-      eputs (" EXEC: "); eputs (file_name); eputs ("\n");
+      eputs (" EXEC: ");
+      eputs (file_name);
+      eputs ("\n");
       int i = 0;
       while (argv[i])
         {
-          eputs (" arg["); eputs (itoa (i)); eputs ("]: "); eputs (argv[i]); eputs ("\n");
+          eputs (" arg[");
+          eputs (itoa (i));
+          eputs ("]: ");
+          eputs (argv[i]);
+          eputs ("\n");
           i++;
         }
     }
