@@ -18,10 +18,12 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
+#include <errno.h>
 #include <stdio.h>
 
 void
-clearerr (FILE *stream)
+clearerr (FILE * stream)
 {
   errno = 0;
 }
