@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2016,2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2016,2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -18,14 +18,17 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
+#include <string.h>
+
 char *__brk = 0;
 
 void *
 malloc (size_t size)
 {
   if (!__brk)
-    __brk = brk (0);
-  if (brk (__brk + size) == (void*)-1)
+    __brk = (char *) brk (0);
+  if (brk (__brk + size) == -1)
     return 0;
   char *p = __brk;
   __brk += size;
