@@ -18,10 +18,10 @@
  * along with GNU Mes.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include <mes/lib.h>
+#include <stdio.h>
 #include <stdlib.h>
-
-#if !__MESC__
-typedef char wchar_t[];
+#include <string.h>
 
 size_t
 mbstowcs (wchar_t * wstring, char const *string, size_t size)
@@ -33,4 +33,3 @@ mbstowcs (wchar_t * wstring, char const *string, size_t size)
   strcpy (wstring, string);
   return strlen (string);
 }
-#endif
