@@ -33,12 +33,12 @@ __argz_count (const char *argz, size_t len)
   size_t count = 0;
   while (len > 0)
     {
-      size_t part_len = strlen(argz);
+      size_t part_len = strlen (argz);
       argz += part_len + 1;
       len -= part_len + 1;
       count++;
     }
   return count;
 }
-libc_hidden_def (__argz_count)
-weak_alias (__argz_count, argz_count)
+
+libc_hidden_def (__argz_count) weak_alias (__argz_count, argz_count)
