@@ -1,6 +1,6 @@
 /* -*-comment-start: "//";comment-end:""-*-
  * GNU Mes --- Maxwell Equations of Software
- * Copyright © 2017,2018 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
+ * Copyright © 2017,2018,2019 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
  *
  * This file is part of GNU Mes.
  *
@@ -19,18 +19,22 @@
  */
 
 #include <setjmp.h>
+#include <stdlib.h>
 
 void
 longjmp (jmp_buf env, int val)
 {
   val = val == 0 ? 1 : val;
-  asm ("mov    0x8(%ebp),%ebp\n\t"     // env*
+  // *INDENT-OFF*
+  asm (
+       "mov    0x8(%ebp),%ebp\n\t"     // env*
 
        "mov    0x4(%ebp),%ebx\n\t"     // env->__pc
        "mov    0x8(%ebp),%esp\n\t"     // env->__sp
        "mov    0x0(%ebp),%ebp\n\t"     // env->__bp
        "jmp    *%ebx\n\t"              // jmp *PC
        );
+  // *INDENT-ON*
   // not reached
   exit (42);
 }
@@ -38,9 +42,9 @@ longjmp (jmp_buf env, int val)
 int
 setjmp (jmp_buf env)
 {
-  long *p = (long*)&env;
+  long *p = (long *) &env;
   env[0].__bp = p[-2];
   env[0].__pc = p[-1];
-  env[0].__sp = (long)&env;
+  env[0].__sp = (long) &env;
   return 0;
 }
